==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/ItemLegendDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { LegendBaseDescriptionMetadata } from "./LegendBaseDescriptionMetadata";
import { ItemLegendDescription } from "./ItemLegendDescription";
/**
 * @hidden
 */
var ItemLegendDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(ItemLegendDescriptionMetadata, _super);
    function ItemLegendDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ItemLegendDescriptionMetadata.e = function (a) {
        a.item("Width", "(w:Width/DimensionTransform,xam:Width/DimensionTransform)String");
        a.item("Height", "(w:Height/DimensionTransform,xam:Height/DimensionTransform)String");
    };
    ItemLegendDescriptionMetadata.b = function (a) {
        if (ItemLegendDescriptionMetadata.a == null) {
            ItemLegendDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ItemLegendDescriptionMetadata.c(ItemLegendDescriptionMetadata.a);
        }
        if (a.j(ItemLegendDescriptionMetadata.a)) {
            return;
        }
        a.y(ItemLegendDescriptionMetadata.a);
    };
    ItemLegendDescriptionMetadata.c = function (a) {
        LegendBaseDescriptionMetadata.c(a);
        a.item("Orientation", "ExportedType:string:LegendOrientation");
        a.item("Orientation@names", "Horizontal;Vertical");
        a.item("TextColor", "String");
        a.item("TextStyle", "String");
        ItemLegendDescriptionMetadata.e(a);
    };
    ItemLegendDescriptionMetadata.d = function (a) {
        ItemLegendDescriptionMetadata.b(a);
        a.aa("ItemLegend", function () { return new ItemLegendDescription(); });
        a.z("ItemLegend", ItemLegendDescriptionMetadata.a);
    };
    ItemLegendDescriptionMetadata.$t = markType(ItemLegendDescriptionMetadata, 'ItemLegendDescriptionMetadata');
    ItemLegendDescriptionMetadata.a = null;
    return ItemLegendDescriptionMetadata;
}(Base));
export { ItemLegendDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/ItemLegendDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { LegendBaseDescriptionMetadata } from "./LegendBaseDescriptionMetadata";
import { ItemLegendDescription } from "./ItemLegendDescription";
/**
 * @hidden
 */
var ItemLegendDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(ItemLegendDescriptionMetadata, _super);
    function ItemLegendDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ItemLegendDescriptionMetadata.e = function (a) {
        a.item("Width", "(w:Width/DimensionTransform,xam:Width/DimensionTransform)String");
        a.item("Height", "(w:Height/DimensionTransform,xam:Height/DimensionTransform)String");
    };
    ItemLegendDescriptionMetadata.b = function (a) {
        if (ItemLegendDescriptionMetadata.a == null) {
            ItemLegendDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ItemLegendDescriptionMetadata.c(ItemLegendDescriptionMetadata.a);
        }
        if (a.k(ItemLegendDescriptionMetadata.a)) {
            return;
        }
        a.aa(ItemLegendDescriptionMetadata.a);
    };
    ItemLegendDescriptionMetadata.c = function (a) {
        LegendBaseDescriptionMetadata.c(a);
        a.item("Orientation", "ExportedType:string:LegendOrientation");
        a.item("Orientation@names", "Horizontal;Vertical");
        a.item("TextColor", "String");
        a.item("TextStyle", "String");
        ItemLegendDescriptionMetadata.e(a);
    };
    ItemLegendDescriptionMetadata.d = function (a) {
        ItemLegendDescriptionMetadata.b(a);
        a.ac("ItemLegend", function () { return new ItemLegendDescription(); });
        a.ab("ItemLegend", ItemLegendDescriptionMetadata.a);
    };
    ItemLegendDescriptionMetadata.$t = markType(ItemLegendDescriptionMetadata, 'ItemLegendDescriptionMetadata');
    ItemLegendDescriptionMetadata.a = null;
    return ItemLegendDescriptionMetadata;
}(Base));
export { ItemLegendDescriptionMetadata };
